==> ae_cloud_storage-0.3.1.tar.gz: ae_cloud_storage-0.3.1/README.md <==
<!-- THIS FILE IS EXCLUSIVELY MAINTAINED by the project ae.ae V0.3.94 -->
<!-- THIS FILE IS EXCLUSIVELY MAINTAINED by the project aedev.tpl_namespace_root V0.3.14 -->
# cloud_storage 0.3.1

[![GitLab develop](https://img.shields.io/gitlab/pipeline/ae-group/ae_cloud_storage/develop?logo=python)](
    https://gitlab.com/ae-group/ae_cloud_storage)
[![LatestPyPIrelease](
    https://img.shields.io/gitlab/pipeline/ae-group/ae_cloud_storage/release?logo=python)](
    https://gitlab.com/ae-group/ae_cloud_storage/-/tree/release)
[![PyPIVersions](https://img.shields.io/pypi/v/ae_cloud_storage)](
    https://pypi.org/project/ae-cloud-storage/#history)

>ae_cloud_storage module 0.3.1.

[![Coverage](https://ae-group.gitlab.io/ae_cloud_storage/coverage.svg)](
    https://ae-group.gitlab.io/ae_cloud_storage/coverage/index.html)
[![MyPyPrecision](https://ae-group.gitlab.io/ae_cloud_storage/mypy.svg)](
    https://ae-group.gitlab.io/ae_cloud_storage/lineprecision.txt)
[![PyLintScore](https://ae-group.gitlab.io/ae_cloud_storage/pylint.svg)](
    https://ae-group.gitlab.io/ae_cloud_storage/pylint.log)

[![PyPIImplementation](https://img.shields.io/pypi/implementation/ae_cloud_storage)](
    https://gitlab.com/ae-group/ae_cloud_storage/)
[![PyPIPyVersions](https://img.shields.io/pypi/pyversions/ae_cloud_storage)](
    https://gitlab.com/ae-group/ae_cloud_storage/)
[![PyPIWheel](https://img.shields.io/pypi/wheel/ae_cloud_storage)](
    https://gitlab.com/ae-group/ae_cloud_storage/)
[![PyPIFormat](https://img.shields.io/pypi/format/ae_cloud_storage)](
    https://pypi.org/project/ae-cloud-storage/)
[![PyPILicense](https://img.shields.io/pypi/l/ae_cloud_storage)](
    https://gitlab.com/ae-group/ae_cloud_storage/-/blob/develop/LICENSE.md)
[![PyPIStatus](https://img.shields.io/pypi/status/ae_cloud_storage)](
    https://libraries.io/pypi/ae-cloud-storage)
[![PyPIDownloads](https://img.shields.io/pypi/dm/ae_cloud_storage)](
    https://pypi.org/project/ae-cloud-storage/#files)


## installation


execute the following command to install the
ae.cloud_storage module
in the currently active virtual environment:
 
```shell script
pip install ae-cloud-storage
```

if you want to contribute to this portion then first fork
[the ae_cloud_storage repository at GitLab](
https://gitlab.com/ae-group/ae_cloud_storage "ae.cloud_storage code repository").
after that pull it to your machine and finally execute the
following command in the root folder of this repository
(ae_cloud_storage):

```shell script
pip install -e .[dev]
```

the last command will install this module portion, along with the tools you need
to develop and run tests or to extend the portion documentation. to contribute only to the unit tests or to the
documentation of this portion, replace the setup extras key `dev` in the above command with `tests` or `docs`
respectively.

more detailed explanations on how to contribute to this project
[are available here](
https://gitlab.com/ae-group/ae_cloud_storage/-/blob/develop/CONTRIBUTING.rst)


## namespace portion documentation

information on the features and usage of this portion are available at
[ReadTheDocs](
https://ae.readthedocs.io/en/latest/_autosummary/ae.cloud_storage.html
"ae_cloud_storage documentation").

==> ae_cloud_storage-0.3.2.tar.gz: ae_cloud_storage-0.3.2/README.md <==
<!-- THIS FILE IS EXCLUSIVELY MAINTAINED by the project ae.ae V0.3.94 -->
<!-- THIS FILE IS EXCLUSIVELY MAINTAINED by the project aedev.tpl_namespace_root V0.3.14 -->
# cloud_storage 0.3.2

[![GitLab develop](https://img.shields.io/gitlab/pipeline/ae-group/ae_cloud_storage/develop?logo=python)](
    https://gitlab.com/ae-group/ae_cloud_storage)
[![LatestPyPIrelease](
    https://img.shields.io/gitlab/pipeline/ae-group/ae_cloud_storage/release0.3.1?logo=python)](
    https://gitlab.com/ae-group/ae_cloud_storage/-/tree/release0.3.1)
[![PyPIVersions](https://img.shields.io/pypi/v/ae_cloud_storage)](
    https://pypi.org/project/ae-cloud-storage/#history)

>ae_cloud_storage module 0.3.2.

[![Coverage](https://ae-group.gitlab.io/ae_cloud_storage/coverage.svg)](
    https://ae-group.gitlab.io/ae_cloud_storage/coverage/index.html)
[![MyPyPrecision](https://ae-group.gitlab.io/ae_cloud_storage/mypy.svg)](
    https://ae-group.gitlab.io/ae_cloud_storage/lineprecision.txt)
[![PyLintScore](https://ae-group.gitlab.io/ae_cloud_storage/pylint.svg)](
    https://ae-group.gitlab.io/ae_cloud_storage/pylint.log)

[![PyPIImplementation](https://img.shields.io/pypi/implementation/ae_cloud_storage)](
    https://gitlab.com/ae-group/ae_cloud_storage/)
[![PyPIPyVersions](https://img.shields.io/pypi/pyversions/ae_cloud_storage)](
    https://gitlab.com/ae-group/ae_cloud_storage/)
[![PyPIWheel](https://img.shields.io/pypi/wheel/ae_cloud_storage)](
    https://gitlab.com/ae-group/ae_cloud_storage/)
[![PyPIFormat](https://img.shields.io/pypi/format/ae_cloud_storage)](
    https://pypi.org/project/ae-cloud-storage/)
[![PyPILicense](https://img.shields.io/pypi/l/ae_cloud_storage)](
    https://gitlab.com/ae-group/ae_cloud_storage/-/blob/develop/LICENSE.md)
[![PyPIStatus](https://img.shields.io/pypi/status/ae_cloud_storage)](
    https://libraries.io/pypi/ae-cloud-storage)
[![PyPIDownloads](https://img.shields.io/pypi/dm/ae_cloud_storage)](
    https://pypi.org/project/ae-cloud-storage/#files)


## installation


execute the following command to install the
ae.cloud_storage module
in the currently active virtual environment:
 
```shell script
pip install ae-cloud-storage
```

if you want to contribute to this portion then first fork
[the ae_cloud_storage repository at GitLab](
https://gitlab.com/ae-group/ae_cloud_storage "ae.cloud_storage code repository").
after that pull it to your machine and finally execute the
following command in the root folder of this repository
(ae_cloud_storage):

```shell script
pip install -e .[dev]
```

the last command will install this module portion, along with the tools you need
to develop and run tests or to extend the portion documentation. to contribute only to the unit tests or to the
documentation of this portion, replace the setup extras key `dev` in the above command with `tests` or `docs`
respectively.

more detailed explanations on how to contribute to this project
[are available here](
https://gitlab.com/ae-group/ae_cloud_storage/-/blob/develop/CONTRIBUTING.rst)


## namespace portion documentation

information on the features and usage of this portion are available at
[ReadTheDocs](
https://ae.readthedocs.io/en/latest/_autosummary/ae.cloud_storage.html
"ae_cloud_storage documentation").
